OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Завдання",
    "Important" : "Важливий",
    "Today" : "Сьогодні",
    "Week" : "Тиждень",
    "All" : "Всі",
    "Current" : "Поточні",
    "Completed" : "Завершені",
    "Delete" : "Видалити",
    "Cancel" : "Скасувати",
    "Change sort order" : "Зміна порядку сортування",
    "Default" : "За замовчуванням",
    "Due date" : "Термін виконання",
    "Start date" : "Дата початку",
    "Priority" : "Перевага",
    "Manually" : "Вручну",
    "Alphabetically" : "За алфавітом",
    "Task is completed" : "Завдання виконано",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завершене завданя","%n завершених завдань","%n завершених завдань","%n завершених завдань"],
    "Tomorrow" : "Завтра",
    "Set start date" : "Встановити дату початку",
    "Set due date" : "Встановіть термін",
    "All day" : "Всі дні",
    "Task not found!" : "Завдання не знайдене!",
    "Edit" : "Редагувати",
    "Download" : "Завантажити",
    "Save" : "Зберегти",
    "New List" : "Новий список",
    "An empty name is not allowed." : "Порожнє поле не допускається.",
    "Settings" : "Налаштування",
    "Visibility of Smart Collections" : "Видимість Smart-колекції",
    "Hidden" : "Прихований",
    "Visible" : "Видимий",
    "Automatic" : "Автоматично"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
